"""
Type annotations for marketplacecommerceanalytics service type definitions.

[Open documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_marketplacecommerceanalytics/type_defs.html)

Usage::

    ```python
    from mypy_boto3_marketplacecommerceanalytics.type_defs import GenerateDataSetRequestRequestTypeDef

    data: GenerateDataSetRequestRequestTypeDef = {...}
    ```
"""
import sys
from datetime import datetime
from typing import Any, Dict, Union

from .literals import DataSetTypeType, SupportDataSetTypeType

if sys.version_info >= (3, 8):
    from typing import TypedDict
else:
    from typing_extensions import TypedDict

__all__ = (
    "GenerateDataSetRequestRequestTypeDef",
    "GenerateDataSetResultTypeDef",
    "ResponseMetadataTypeDef",
    "StartSupportDataExportRequestRequestTypeDef",
    "StartSupportDataExportResultTypeDef",
)

_RequiredGenerateDataSetRequestRequestTypeDef = TypedDict(
    "_RequiredGenerateDataSetRequestRequestTypeDef",
    {
        "dataSetType": DataSetTypeType,
        "dataSetPublicationDate": Union[datetime, str],
        "roleNameArn": str,
        "destinationS3BucketName": str,
        "snsTopicArn": str,
    },
)
_OptionalGenerateDataSetRequestRequestTypeDef = TypedDict(
    "_OptionalGenerateDataSetRequestRequestTypeDef",
    {
        "destinationS3Prefix": str,
        "customerDefinedValues": Dict[str, str],
    },
    total=False,
)

class GenerateDataSetRequestRequestTypeDef(
    _RequiredGenerateDataSetRequestRequestTypeDef, _OptionalGenerateDataSetRequestRequestTypeDef
):
    pass

GenerateDataSetResultTypeDef = TypedDict(
    "GenerateDataSetResultTypeDef",
    {
        "dataSetRequestId": str,
        "ResponseMetadata": "ResponseMetadataTypeDef",
    },
)

ResponseMetadataTypeDef = TypedDict(
    "ResponseMetadataTypeDef",
    {
        "RequestId": str,
        "HostId": str,
        "HTTPStatusCode": int,
        "HTTPHeaders": Dict[str, Any],
        "RetryAttempts": int,
    },
)

_RequiredStartSupportDataExportRequestRequestTypeDef = TypedDict(
    "_RequiredStartSupportDataExportRequestRequestTypeDef",
    {
        "dataSetType": SupportDataSetTypeType,
        "fromDate": Union[datetime, str],
        "roleNameArn": str,
        "destinationS3BucketName": str,
        "snsTopicArn": str,
    },
)
_OptionalStartSupportDataExportRequestRequestTypeDef = TypedDict(
    "_OptionalStartSupportDataExportRequestRequestTypeDef",
    {
        "destinationS3Prefix": str,
        "customerDefinedValues": Dict[str, str],
    },
    total=False,
)

class StartSupportDataExportRequestRequestTypeDef(
    _RequiredStartSupportDataExportRequestRequestTypeDef,
    _OptionalStartSupportDataExportRequestRequestTypeDef,
):
    pass

StartSupportDataExportResultTypeDef = TypedDict(
    "StartSupportDataExportResultTypeDef",
    {
        "dataSetRequestId": str,
        "ResponseMetadata": "ResponseMetadataTypeDef",
    },
)



"""
Type annotations for marketplacecommerceanalytics service literal definitions.

[Open documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_marketplacecommerceanalytics/literals.html)

Usage::

    ```python
    from mypy_boto3_marketplacecommerceanalytics.literals import DataSetTypeType

    data: DataSetTypeType = "customer_profile_by_geography"
    ```
"""
import sys

if sys.version_info >= (3, 8):
    from typing import Literal
else:
    from typing_extensions import Literal


__all__ = ("DataSetTypeType", "SupportDataSetTypeType")


DataSetTypeType = Literal[
    "customer_profile_by_geography",
    "customer_profile_by_industry",
    "customer_profile_by_revenue",
    "customer_subscriber_annual_subscriptions",
    "customer_subscriber_hourly_monthly_subscriptions",
    "daily_business_canceled_product_subscribers",
    "daily_business_fees",
    "daily_business_free_trial_conversions",
    "daily_business_new_instances",
    "daily_business_new_product_subscribers",
    "daily_business_usage_by_instance_type",
    "disbursed_amount_by_age_of_disbursed_funds",
    "disbursed_amount_by_age_of_past_due_funds",
    "disbursed_amount_by_age_of_uncollected_funds",
    "disbursed_amount_by_customer_geo",
    "disbursed_amount_by_instance_hours",
    "disbursed_amount_by_product",
    "disbursed_amount_by_product_with_uncollected_funds",
    "disbursed_amount_by_uncollected_funds_breakdown",
    "monthly_revenue_annual_subscriptions",
    "monthly_revenue_billing_and_revenue_data",
    "monthly_revenue_field_demonstration_usage",
    "monthly_revenue_flexible_payment_schedule",
    "sales_compensation_billed_revenue",
    "us_sales_and_use_tax_records",
]
SupportDataSetTypeType = Literal[
    "customer_support_contacts_data", "test_customer_support_contacts_data"
]



"""
Type annotations for marketplacecommerceanalytics service client.

[Open documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_marketplacecommerceanalytics/client.html)

Usage::

    ```python
    import boto3
    from mypy_boto3_marketplacecommerceanalytics import MarketplaceCommerceAnalyticsClient

    client: MarketplaceCommerceAnalyticsClient = boto3.client("marketplacecommerceanalytics")
    ```
"""
from datetime import datetime
from typing import Any, Dict, Type, Union

from botocore.client import BaseClient, ClientMeta

from .literals import DataSetTypeType, SupportDataSetTypeType
from .type_defs import GenerateDataSetResultTypeDef, StartSupportDataExportResultTypeDef

__all__ = ("MarketplaceCommerceAnalyticsClient",)


class BotocoreClientError(BaseException):
    MSG_TEMPLATE: str

    def __init__(self, error_response: Dict[str, Any], operation_name: str) -> None:
        self.response: Dict[str, Any]
        self.operation_name: str


class Exceptions:
    ClientError: Type[BotocoreClientError]
    MarketplaceCommerceAnalyticsException: Type[BotocoreClientError]


class MarketplaceCommerceAnalyticsClient(BaseClient):
    """
    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.5/reference/services/marketplacecommerceanalytics.html#MarketplaceCommerceAnalytics.Client)
    [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_marketplacecommerceanalytics/client.html)
    """

    meta: ClientMeta

    @property
    def exceptions(self) -> Exceptions:
        """
        MarketplaceCommerceAnalyticsClient exceptions.
        """

    def can_paginate(self, operation_name: str) -> bool:
        """
        Check if an operation can be paginated.

        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.5/reference/services/marketplacecommerceanalytics.html#MarketplaceCommerceAnalytics.Client.can_paginate)
        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_marketplacecommerceanalytics/client.html#can_paginate)
        """

    def generate_data_set(
        self,
        *,
        dataSetType: DataSetTypeType,
        dataSetPublicationDate: Union[datetime, str],
        roleNameArn: str,
        destinationS3BucketName: str,
        snsTopicArn: str,
        destinationS3Prefix: str = None,
        customerDefinedValues: Dict[str, str] = None
    ) -> GenerateDataSetResultTypeDef:
        """
        Given a data set type and data set publication date, asynchronously publishes
        the requested data set to the specified S3 bucket and notifies the specified SNS
        topic once the data is available.

        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.5/reference/services/marketplacecommerceanalytics.html#MarketplaceCommerceAnalytics.Client.generate_data_set)
        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_marketplacecommerceanalytics/client.html#generate_data_set)
        """

    def generate_presigned_url(
        self,
        ClientMethod: str,
        Params: Dict[str, Any] = None,
        ExpiresIn: int = 3600,
        HttpMethod: str = None,
    ) -> str:
        """
        Generate a presigned url given a client, its method, and arguments.

        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.5/reference/services/marketplacecommerceanalytics.html#MarketplaceCommerceAnalytics.Client.generate_presigned_url)
        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_marketplacecommerceanalytics/client.html#generate_presigned_url)
        """

    def start_support_data_export(
        self,
        *,
        dataSetType: SupportDataSetTypeType,
        fromDate: Union[datetime, str],
        roleNameArn: str,
        destinationS3BucketName: str,
        snsTopicArn: str,
        destinationS3Prefix: str = None,
        customerDefinedValues: Dict[str, str] = None
    ) -> StartSupportDataExportResultTypeDef:
        """
        Given a data set type and a from date, asynchronously publishes the requested
        customer support data to the specified S3 bucket and notifies the specified SNS
        topic once the data is available.

        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.5/reference/services/marketplacecommerceanalytics.html#MarketplaceCommerceAnalytics.Client.start_support_data_export)
        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_marketplacecommerceanalytics/client.html#start_support_data_export)
        """
